﻿using System;
using System.Collections.Generic;
using System.Text;
using FTGate.Framework;

public class MailboxExtension : MailboxBehaviour
{
    /// 
    /// .net mailbox processing class
    /// you may exclude any functions you do not require
    /// 

    /// <summary>
    /// Called by a mailbox prior to its own processing
    /// </summary> 
    public ProcessMessageReturnType OnProcessMessage(MailMessage message)
    {
        Log log = new Log();
        log.Write(LogType.Debug, "ProcessMessage called for mailbox " + mailbox.emailAddress+" : "+count);
        ProcessMessageReturnType retVal = ProcessMessageReturnType.Continue;
        try
        {
            // do whatever you want in here
            int type = 0;
            switch (type)
            {
                case 0: retVal = ProcessMessageReturnType.Continue; // continue with normal processing
                case 1: retVal = ProcessMessageReturnType.BypassRules; // store message without running mailbox rules
                case 2: retVal = ProcessMessageReturnType.RequestDelete; // request that ftgate dlete the file
                case 3: retVal = ProcessMessageReturnType.Error; // tell ftgate an error occurred but continue processing
                case 4: retVal = ProcessMessageReturnType.MessageDeleted; // tell ftgate we deleted the message (.txt, .wrk, .fif files)
            }
        }
        catch (Exception e)
        {
            retVal = ProcessMessageReturnType.Error; // error case
        }
        return retVal;
    }

    /// <summary>
    /// Called by a mailbox if a rule is hit that is set to use dotnet
    /// </summary> 
    public ProcessMessageReturnType OnProcessRule(string ruleName, MailMessage message)
    {
        Log log = new Log();
        log.Write(LogType.Debug, "ProcessRule called for mailbox " + mailbox.emailAddress);
        ProcessMessageReturnType retVal = ProcessMessageReturnType.Continue;
        try
        {
            // same handling as OnProcessMessage but called from a rule
        }
        catch (Exception e)
        {
            retVal = ProcessMessageReturnType.Error; // error case
        }
        return retVal;
    }

    /// <summary>
    /// Called by a mailbox to authenticate a user login (webmail/imap/pop/smtp)
    /// not called for autosignin webmail connections
    /// </summary> 
    public AuthenticationState OnAuthenticate(string password)
    {
        Log log = new Log();
        log.Write(LogType.Debug, "Trying to authenticate " + mailbox.emailAddress);
        if (mailbox.emailAddress == "a.kaplan@test4.ftgate.com")
            return AuthenticationState.Authenticated;
        //return AuthenticationState.Failed;
        return AuthenticationState.UseDefault;
    }

    /// <summary>
    /// Called once per mailbox at start of processing
    /// return true to remove the imap locks and process locks on the .net functions
    /// this will significantly improve performance but should not be used if the mailbox will
    /// be accessed by IMAP or POP3 while .net calls can be made as it can cause the IMAP clients to
    /// report errors and maybe crash
    /// in addition you are responsible for ensuring that your class is thread safe as it will be called by multiple
    /// concurrent threads
    /// </summary> 
    public bool Desynchronize()
    {
        return false;
        //return true;
    }

}

